@@ -18,7 +18,7 @@
  *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  *  Boston, MA  02111-1307  USA
  *
- *  $Id: uim-tomoe-gtk.c,v 1.10 2005/10/06 06:30:33 makeinu Exp $
+ *  $Id: uim-tomoe-gtk.c,v 1.11 2006/11/13 06:11:15 makeinu Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,11 +37,17 @@ static int uim_fd = -1;
 
 
 static void
-char_clicked_cb (TomoeCandidatesView *view, gpointer user_data)
+char_clicked_cb (TomoeCharTable *view, gpointer user_data)
 {
-    gchar *str = tomoe_candidates_view_get_selected_letter (view);
-
+    tomoe_char *ch = tomoe_char_table_get_selected (view);
     GString *tmp = g_string_new ("commit_string\n");
+    const char *str;
+
+    if (!ch) return;
+
+    str = tomoe_char_getCode (ch);
+    if (!str) return;
+
     g_string_append (tmp, str);
     g_string_append (tmp, "\n");
 
@@ -87,6 +93,10 @@ quit (void)
 int
 main (int argc, char *argv[])
 {
+    GtkWidget *window;
+    TomoeWindow *tomoe;
+    TomoeStrokeSearch *page;
+
     setlocale (LC_ALL, "");
     bindtextdomain (PACKAGE, LOCALEDIR);
     textdomain (PACKAGE);
@@ -97,7 +107,7 @@ main (int argc, char *argv[])
     /* confirm helper connection */
     check_helper_connection ();
 
-    GtkWidget *window = tomoe_window_new ();
+    window = tomoe_window_new ();
     gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
     gtk_widget_show (window);
     g_signal_connect (G_OBJECT (window), "response",
@@ -105,11 +115,11 @@ main (int argc, char *argv[])
     g_signal_connect (GTK_OBJECT (window), "destroy",
                       G_CALLBACK (quit), NULL);
 
-    /* add software keyboard button */
-    TomoeWindow *tomoe = TOMOE_WINDOW (window);
 
     /* add hooks */
-    g_signal_connect (G_OBJECT (tomoe->candidates_view), "selected",
+    tomoe = TOMOE_WINDOW (window);
+    page = TOMOE_STROKE_SEARCH (tomoe->handwriting_page);
+    g_signal_connect (G_OBJECT (page->candidates_view), "selected",
                       G_CALLBACK (char_clicked_cb),
                       (gpointer) tomoe);
 
